You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by ch...@apache.org on 2005/04/29 06:08:35 UTC

svn commit: r165258 - in /webservices/axis/trunk/java/modules: samples/test/org/apache/axis/engine/ xml/src/org/apache/axis/om/ xml/src/org/apache/axis/om/impl/llom/ xml/src/org/apache/axis/om/impl/llom/soap12/ xml/test/org/apache/axis/om/

Author: chinthaka
Date: Thu Apr 28 21:08:34 2005
New Revision: 165258

URL: http://svn.apache.org/viewcvs?rev=165258&view=rev
Log:
Added SOAP 1.2 stuff

Added:
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCode.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCodeValue.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultDetail.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultNode.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultReason.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultRole.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultSubCode.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPSubCodeValue.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPText.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaulReasonImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPTextImpl.java
Modified:
    webservices/axis/trunk/java/modules/samples/test/org/apache/axis/engine/CallUnregisteredServiceTest.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPBody.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFault.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeader.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeaderBlock.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/OMElementImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPEnvelopeImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaultImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderBlockImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderImpl.java
    webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/soap12/SOAP12Constants.java
    webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/OMHeaderBlockTest.java
    webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/SOAPFaultTest.java

Modified: webservices/axis/trunk/java/modules/samples/test/org/apache/axis/engine/CallUnregisteredServiceTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/samples/test/org/apache/axis/engine/CallUnregisteredServiceTest.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/samples/test/org/apache/axis/engine/CallUnregisteredServiceTest.java (original)
+++ webservices/axis/trunk/java/modules/samples/test/org/apache/axis/engine/CallUnregisteredServiceTest.java Thu Apr 28 21:08:34 2005
@@ -85,7 +85,7 @@
 
             SOAPBody sb = resEnv.getBody();
             if (sb.hasFault()) {
-                throw new AxisFault(sb.getFault().getFaultString());
+                throw new AxisFault(sb.getFault().getReason().getSOAPText().getText());
             }
             fail("The test must fail due to wrong service Name");
 

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPBody.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPBody.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPBody.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPBody.java Thu Apr 28 21:08:34 2005
@@ -61,4 +61,6 @@
      * @throws OMException
      */
     public abstract void addFault(SOAPFault soapFault) throws OMException;
+
+
 }

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFault.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFault.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFault.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFault.java Thu Apr 28 21:08:34 2005
@@ -38,92 +38,41 @@
  * recipient.
  */
 public interface SOAPFault extends OMElement {
-    /**
-     * Sets this <CODE>SOAPFault</CODE> object with the given
-     * fault code.
-     * <P>Fault codes, which given information about the fault,
-     * are defined in the SOAP 1.1 specification.</P>
-     *
-     * @param faultCode a <CODE>QName</CODE> giving
-     *                  the fault code to be set; must be one of the fault codes
-     *                  defined in the SOAP 1.1 specification
-     * @throws OMException if there was an error in
-     *                     adding the <CODE>faultCode</CODE> to the underlying XML
-     *                     tree.
-     * @see #getFaultCode() getFaultCode()
-     */
-    public abstract void setFaultCode(QName faultCode) throws OMException;
-
-    /**
-     * Gets the fault code for this <CODE>SOAPFault</CODE>
-     * object.
-     *
-     * @return a <CODE>String</CODE> with the fault code
-     * @see #setFaultCode(QName) setFaultCode(QName)
-     */
-    public abstract QName getFaultCode();
 
     /**
-     * Sets this <CODE>SOAPFault</CODE> object with the given
-     * fault actor.
-     * <P>The fault actor is the recipient in the message path who
-     * caused the fault to happen.</P>
-     *
-     * @param faultActor a <CODE>String</CODE>
-     *                   identifying the actor that caused this <CODE>
-     *                   SOAPFault</CODE> object
-     * @throws OMException if there was an error in
-     *                     adding the <CODE>faultActor</CODE> to the underlying XML
-     *                     tree.
-     * @see #getFaultActor() getFaultActor()
+     * SOAPFaultCode is a mandatory item in a Fault, in SOAP 1.2 specification
+     * @param soapFaultCode
      */
-    public abstract void setFaultActor(String faultActor) throws OMException;
+    public void setCode(SOAPFaultCode soapFaultCode);
+    public SOAPFaultCode getCode();
 
     /**
-     * Gets the fault actor for this <CODE>SOAPFault</CODE>
-     * object.
-     *
-     * @return a <CODE>String</CODE> giving the actor in the message
-     *         path that caused this <CODE>SOAPFault</CODE> object
-     * @see #setFaultActor(String) setFaultActor(java.lang.String)
+     * SOAPFaultReason is a mandatory item in a Fault, in SOAP 1.2 specification
+     * @param reason
      */
-    public abstract String getFaultActor();
+    public void setReason(SOAPFaultReason reason);
+    public SOAPFaultReason getReason();
 
     /**
-     * Sets the fault string for this <CODE>SOAPFault</CODE>
-     * object to the given string.
-     *
-     * @param faultString a <CODE>String</CODE>
-     *                    giving an explanation of the fault
-     * @throws OMException if there was an error in
-     *                     adding the <CODE>faultString</CODE> to the underlying XML
-     *                     tree.
-     * @see #getFaultString() getFaultString()
+     * SOAPFaultNode is an optional item in a Fault, in SOAP 1.2 specification
+     * @param node
      */
-    public abstract void setFaultString(String faultString) throws OMException;
+    public void setNode(SOAPFaultNode node);
+    public SOAPFaultNode getNode();
 
     /**
-     * Gets the fault string for this <CODE>SOAPFault</CODE>
-     * object.
-     *
-     * @return a <CODE>String</CODE> giving an explanation of the
-     *         fault
+     * SOAPFaultRole is an optional item in a Fault, in SOAP 1.2 specification
+     * @param role
      */
-    public abstract String getFaultString();
+    public void setRole(SOAPFaultRole role);
+    public SOAPFaultRole getRole();
 
     /**
-     * This will set the given omnode under the detail element of SOAP fault
-     *
+     * SOAPFaultRole is an optional item in a Fault, in SOAP 1.2 specification
      * @param detail
      */
-    public abstract void setDetailInformation(OMNode detail);
-
-    /**
-     * Method getDetailInformation
-     *
-     * @return
-     */
-    public abstract OMNode getDetailInformation();
+    public void setDetail(SOAPFaultDetail detail);
+    public SOAPFaultDetail getDetail();
 
     /**
      * Method getException

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCode.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCode.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCode.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCode.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,44 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPFaultCode extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    /**
+     * @param value
+     */
+    public void addValue(SOAPFaultCodeValue value);
+
+    /**
+     * @return
+     */
+    public SOAPFaultCodeValue getValue();
+
+    /**
+     * @param value
+     */
+    public void addSubCode(SOAPFaultSubCode value);
+
+    /**
+     * @return
+     */
+    public SOAPFaultSubCode getSubCode();
+
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCodeValue.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCodeValue.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCodeValue.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultCodeValue.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,36 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPFaultCodeValue extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    /**
+     *
+     * @param envFaultCodeEnum - Look in @see SOAP12Constants class for
+     * valid SOAP fault codes covering high level SOAP faults. Look for
+     * constants starting with SOAP_FAULT_VALUE_
+     */
+    public void setValue(String envFaultCodeEnum);
+
+    /**
+     * @return
+     */
+    public String getValue();
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultDetail.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultDetail.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultDetail.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultDetail.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,39 @@
+package org.apache.axis.om;
+
+import java.util.Iterator;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+
+/**
+ * The Detail element information item is intended for carrying application
+ * specific error information related to the SOAP Body .
+ * <p/>
+ * The Detail element information item has:
+ *      A [local name] of Detail .
+ *      A [namespace name] of http://www.w3.org/2003/05/soap-envelope .
+ *      Zero or more attribute information items in its [attributes] property.
+ *      Zero or more child element information items in its [children] property.
+ */
+public interface SOAPFaultDetail extends OMElement {
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+    public void addDetailEntry(OMElement detailElement);
+    public Iterator getAllDetailEntries();
+    
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultNode.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultNode.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultNode.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultNode.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,37 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPFaultNode extends OMElement {
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    /**
+     * each SOAP node is identified by a URI. The value of the Node element
+     * information item is the URI that identifies the SOAP node that generated
+     * the fault. SOAP nodes that do not act as the ultimate SOAP receiver MUST
+     * include this element information item. An ultimate SOAP receiver MAY
+     * include this element information item to indicate explicitly that it
+     * generated the fault.
+     *
+     * @param uri
+     */
+    public void setNodeValue(String uri);
+
+    public String getNodeValue();
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultReason.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultReason.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultReason.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultReason.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,26 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPFaultReason extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    public void setSOAPText(SOAPText soapText);
+    public SOAPText getSOAPText();
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultRole.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultRole.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultRole.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultRole.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,42 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+
+/**
+ * The Role element information item identifies the role the node was operating
+ * in at the point the fault occurred.
+ * <p/>
+ * The Role element information item has:
+ *      A [local name] of Role .
+ *      A [namespace name] of http://www.w3.org/2003/05/soap-envelope .
+ */
+public interface SOAPFaultRole extends OMElement {
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+    
+    /**
+     * The value of the Role element information item MUST be one of the roles
+     * assumed by the node during processing of the message
+     *
+     * @param uri
+     */
+    public void setRoleValue(String uri);
+
+    public String getRoleValue();
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultSubCode.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultSubCode.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultSubCode.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPFaultSubCode.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,38 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPFaultSubCode extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    /**
+     * Fault SubCode contain only one mandatory Value child. This value child contains a QName
+     * @param soapSubCodeValue
+     */
+    public void addValue(SOAPSubCodeValue soapSubCodeValue);
+    public SOAPSubCodeValue getValue();
+
+
+    /**
+     * Fault SubCode can contain an optional SubCode
+     * @param subCode
+     */
+    public void addSubCode(SOAPFaultSubCode subCode);
+    public SOAPFaultSubCode getSubCode();
+}

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeader.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeader.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeaderBlock.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeaderBlock.java Thu Apr 28 21:08:34 2005
@@ -30,14 +30,14 @@
      * default value of an actor is: <CODE>
      * OMConstants.URI_SOAP_ACTOR_NEXT</CODE>
      *
-     * @param actorURI a <CODE>String</CODE> giving
+     * @param roleURI a <CODE>String</CODE> giving
      *                 the URI of the actor to set
      * @throws java.lang.IllegalArgumentException
      *          if
      *          there is a problem in setting the actor.
-     * @see #getActor() getActor()
+     * @see #getRole() getRole()
      */
-    public abstract void setActor(String actorURI);
+    public abstract void setRole(String roleURI);
 
     /**
      * Returns the uri of the actor associated with this <CODE>
@@ -45,9 +45,9 @@
      *
      * @return a <CODE>String</CODE> giving the URI of the
      *         actor
-     * @see #setActor(java.lang.String) setActor(java.lang.String)
+     * @see #setRole(java.lang.String) setRole(java.lang.String)
      */
-    public abstract String getActor();
+    public abstract String getRole();
 
     /**
      * Sets the mustUnderstand attribute for this <CODE>

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPSubCodeValue.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPSubCodeValue.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPSubCodeValue.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPSubCodeValue.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,23 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPSubCodeValue extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+}

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPText.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPText.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPText.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPText.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,34 @@
+package org.apache.axis.om;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public interface SOAPText extends OMElement{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    /**
+     * lang is a mandatory attribute within the SOAPText which must have
+     * SOAP12Constants.SOAP_FAULT_TEXT_LANG_ATTR_NS_URI as the namespace URI and
+     * SOAP12constants.SOAP_FAULT_TEXT_LANG_ATTR_NS_PREFIX or a capitalization thereof as the prefix
+     * @param lang
+     */
+    public void setLang(String lang);
+    public String getLang();
+
+    
+}

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/OMElementImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/OMElementImpl.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/OMElementImpl.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/OMElementImpl.java Thu Apr 28 21:08:34 2005
@@ -223,12 +223,9 @@
         OMNode omNode = null;
         if (omChildrenQNameIterator.hasNext()) {
             omNode = (OMNode) omChildrenQNameIterator.next();
-            return (OMNode.ELEMENT_NODE == omNode.getType()) ? (OMElement) omNode : null;
-        }else{
-            return null;
         }
 
-        
+        return ((omNode != null) && (OMNode.ELEMENT_NODE == omNode.getType())) ? (OMElement) omNode : null;
 
     }
 

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPEnvelopeImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPEnvelopeImpl.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPEnvelopeImpl.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPEnvelopeImpl.java Thu Apr 28 21:08:34 2005
@@ -15,21 +15,17 @@
  */
 package org.apache.axis.om.impl.llom;
 
-import org.apache.axis.om.OMConstants;
-import org.apache.axis.om.OMElement;
-import org.apache.axis.om.OMException;
-import org.apache.axis.om.OMNamespace;
-import org.apache.axis.om.OMXMLParserWrapper;
-import org.apache.axis.om.SOAPBody;
-import org.apache.axis.om.SOAPEnvelope;
-import org.apache.axis.om.SOAPHeader;
-import org.apache.axis.om.OMNode;
+import org.apache.axis.om.*;
 
 /**
  * Class SOAPEnvelopeImpl
  */
 public class SOAPEnvelopeImpl extends OMElementImpl
         implements SOAPEnvelope, OMConstants {
+
+    private SOAPBody soapBody;
+    private SOAPHeader soapHeader;
+
     /**
      * @param builder
      */
@@ -56,55 +52,55 @@
 
     /**
      * Returns the <CODE>SOAPHeader</CODE> object for this <CODE>
-     * SOAPEnvelope</CODE> object.
-     * <P> This SOAPHeader will just be a container for all the headers in the
-     * <CODE>OMMessage</CODE>
-     * </P>
+     * SOAPEnvelope</CODE> object. <P> This SOAPHeader will just be a container
+     * for all the headers in the <CODE>OMMessage</CODE> </P>
      *
-     * @return the <CODE>SOAPHeader</CODE> object or <CODE>
-     *         null</CODE> if there is none
-     * @throws org.apache.axis.om.OMException if there is a problem
-     *                                        obtaining the <CODE>SOAPHeader</CODE> object
+     * @return the <CODE>SOAPHeader</CODE> object or <CODE> null</CODE> if there
+     *         is none
+     * @throws org.apache.axis.om.OMException if there is a problem obtaining
+     *                                        the <CODE>SOAPHeader</CODE>
+     *                                        object
      * @throws OMException
      */
     public SOAPHeader getHeader() throws OMException {
-        OMElement element = getFirstElement();
-        if (SOAPConstants.HEADER_LOCAL_NAME.equals(element.getLocalName())) {
-            return (SOAPHeader) element;
+        if (soapHeader == null) {
+            OMElement element = getFirstElement();
+            if (SOAPConstants.HEADER_LOCAL_NAME.equals(element.getLocalName())) {
+                soapHeader = (SOAPHeader) element;
+            }
         }
-        return null;
+        return soapHeader;
     }
 
     /**
-     * Returns the <CODE>SOAPBody</CODE> object associated with
-     * this <CODE>SOAPEnvelope</CODE> object.
-     * <P> This SOAPBody will just be a container for all the BodyElements in the
-     * <CODE>OMMessage</CODE>
-     * </P>
+     * Returns the <CODE>SOAPBody</CODE> object associated with this
+     * <CODE>SOAPEnvelope</CODE> object. <P> This SOAPBody will just be a
+     * container for all the BodyElements in the <CODE>OMMessage</CODE> </P>
      *
      * @return the <CODE>SOAPBody</CODE> object for this <CODE>
-     *         SOAPEnvelope</CODE> object or <CODE>null</CODE> if there
-     *         is none
-     * @throws org.apache.axis.om.OMException if there is a problem
-     *                                        obtaining the <CODE>SOAPBody</CODE> object
+     *         SOAPEnvelope</CODE> object or <CODE>null</CODE> if there is none
+     * @throws org.apache.axis.om.OMException if there is a problem obtaining
+     *                                        the <CODE>SOAPBody</CODE> object
      * @throws OMException
      */
     public SOAPBody getBody() throws OMException {
-        OMElement element = getFirstElement();
-        if (SOAPConstants.BODY_LOCAL_NAME.equals(element.getLocalName())) {
-            return (SOAPBody) element;
-        }else{
-            OMNode node = element.getNextSibling();
-            while(node.getType()!=OMNode.ELEMENT_NODE){
-               node = node.getNextSibling();
-            }
-            element =(OMElement)node;
-            
+        if (soapBody == null) {
+            OMElement element = getFirstElement();
             if (SOAPConstants.BODY_LOCAL_NAME.equals(element.getLocalName())) {
-                return (SOAPBody) element;
+                soapBody = (SOAPBody) element;
+            } else {
+                OMNode node = element.getNextSibling();
+                while (node.getType() != OMNode.ELEMENT_NODE) {
+                    node = node.getNextSibling();
+                }
+                element = (OMElement) node;
+
+                if (SOAPConstants.BODY_LOCAL_NAME.equals(element.getLocalName())) {
+                    soapBody = (SOAPBody) element;
+                }
             }
         }
-        return null;
+        return soapBody;
     }
 
     /**

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaulReasonImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaulReasonImpl.java?rev=165258&view=auto
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaulReasonImpl.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaulReasonImpl.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,47 @@
+package org.apache.axis.om.impl.llom;
+
+import org.apache.axis.om.OMElement;
+import org.apache.axis.om.SOAPFaultReason;
+import org.apache.axis.om.SOAPText;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public class SOAPFaulReasonImpl extends OMElementImpl implements SOAPFaultReason {
+
+    
+    /**
+     * @param parent
+     * @param parent
+     */
+    public SOAPFaulReasonImpl(OMElement parent) {
+        super(parent);
+    }
+
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+
+    private SOAPText soapText;
+
+    public void setSOAPText(SOAPText soapText) {
+        this.soapText = soapText;
+    }
+
+    public SOAPText getSOAPText() {
+        return this.soapText;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+}

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaultImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaultImpl.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaultImpl.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPFaultImpl.java Thu Apr 28 21:08:34 2005
@@ -15,15 +15,7 @@
  */
 package org.apache.axis.om.impl.llom;
 
-import org.apache.axis.om.OMConstants;
-import org.apache.axis.om.OMElement;
-import org.apache.axis.om.OMException;
-import org.apache.axis.om.OMFactory;
-import org.apache.axis.om.OMNamespace;
-import org.apache.axis.om.OMNode;
-import org.apache.axis.om.OMText;
-import org.apache.axis.om.OMXMLParserWrapper;
-import org.apache.axis.om.SOAPFault;
+import org.apache.axis.om.*;
 import org.apache.axis.om.impl.llom.soap11.SOAP11Constants;
 
 import javax.xml.namespace.QName;
@@ -94,12 +86,12 @@
     }
 
     /**
-     * Method setFaultCode
+     * Method setCode
      *
      * @param faultCode
      * @throws OMException
      */
-    public void setFaultCode(QName faultCode) throws OMException {
+    public void setCode(SOAPFaultCode faultCode) throws OMException {
         if (faultCodeElement != null) {
             faultCodeElement.detach();
         }
@@ -107,36 +99,75 @@
         new OMElementImpl(SOAPConstants.SOAPFAULT_CODE_LOCAL_NAME, this.ns);
         this.addChild(faultCodeElement);
         faultCodeElement.addChild(new OMTextImpl(faultCodeElement,
-                        faultCode.getPrefix() + ':'
-                                + faultCode.getLocalPart()));
+                        faultCode.getNamespace().getPrefix() + ':'
+                                + faultCode.getLocalName()));
     }
 
     /**
-     * Method getFaultCode
+     * Method getCode
      *
      * @return
      */
-    public QName getFaultCode() {
-        if (faultCodeElement != null) {
-            Iterator childrenIter = faultCodeElement.getChildren();
-            while (childrenIter.hasNext()) {
-                Object o = childrenIter.next();
-                if ((o instanceof OMText)
-                        && !((OMText) o).getText().trim().equals("")) {
-                    String[] strings = ((OMText) o).getText().split(":");
-                    return new QName("", strings[1], strings[0]);
-                }
-            }
-        } else {
-            faultCodeElement =  this.getFirstChildWithName(
-                    new QName(
-                            this.ns.getName(), SOAPConstants.SOAPFAULT_CODE_LOCAL_NAME,
-                            this.ns.getPrefix()));
-            if (faultCodeElement != null) {
-                return this.getFaultCode();
-            }
-        }
+    public SOAPFaultCode getCode() {
+//        if (faultCodeElement != null) {
+//            Iterator childrenIter = faultCodeElement.getChildren();
+//            while (childrenIter.hasNext()) {
+//                Object o = childrenIter.next();
+//                if ((o instanceof OMText)
+//                        && !((OMText) o).getText().trim().equals("")) {
+//                    String[] strings = ((OMText) o).getText().split(":");
+//                    return new QName("", strings[1], strings[0]);
+//                }
+//            }
+//        } else {
+//            faultCodeElement =  this.getFirstChildWithName(
+//                    new QName(
+//                            this.ns.getName(), SOAPConstants.SOAPFAULT_CODE_LOCAL_NAME,
+//                            this.ns.getPrefix()));
+//            if (faultCodeElement != null) {
+//                return this.getCode();
+//            }
+//        }
         return null;
+    }
+
+    public void setReason(SOAPFaultReason reason) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public SOAPFaultReason getReason() {
+
+
+        SOAPFaultReason faultReason = new SOAPFaulReasonImpl(this);
+        SOAPText soapText = new SOAPTextImpl(faultReason);
+        soapText.setText(this.getFaultString());
+
+        faultReason.setSOAPText(soapText);
+        return faultReason;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public void setNode(SOAPFaultNode node) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public SOAPFaultNode getNode() {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public void setRole(SOAPFaultRole role) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public SOAPFaultRole getRole() {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public void setDetail(SOAPFaultDetail detail) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public SOAPFaultDetail getDetail() {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
     /**

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderBlockImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderBlockImpl.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderBlockImpl.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderBlockImpl.java Thu Apr 28 21:08:34 2005
@@ -61,9 +61,9 @@
      *                 the URI of the actor to set
      * @throws IllegalArgumentException if
      *                                  there is a problem in setting the actor.
-     * @see #getActor() getActor()
+     * @see #getRole() getRole()
      */
-    public void setActor(String actorURI) {
+    public void setRole(String actorURI) {
         setAttribute(SOAPConstants.ATTR_ACTOR, actorURI);
     }
 
@@ -92,9 +92,9 @@
      *
      * @return a <CODE>String</CODE> giving the URI of the
      *         actor
-     * @see #setActor(String) setActor(java.lang.String)
+     * @see #setRole(String) setRole(java.lang.String)
      */
-    public String getActor() {
+    public String getRole() {
         return getAttribute(SOAPConstants.ATTR_ACTOR);
     }
 

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderImpl.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPTextImpl.java (added)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPTextImpl.java Thu Apr 28 21:08:34 2005
@@ -0,0 +1,41 @@
+package org.apache.axis.om.impl.llom;
+
+import org.apache.axis.om.OMElement;
+import org.apache.axis.om.SOAPText;
+
+/**
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * <p/>
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ * <p/>
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * <p/>
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ * <p/>
+ */
+public class SOAPTextImpl extends OMElementImpl implements SOAPText{
+    /**
+     * Eran Chinthaka (chinthaka@apache.org)
+     */
+    /**
+     * @param parent
+     * @param parent
+     */
+    public SOAPTextImpl(OMElement parent) {
+        super(parent);
+    }
+
+    public void setLang(String lang) {
+        //To change body of implemented methods use File | Settings | File Templates.
+    }
+
+    public String getLang() {
+        return null;  //To change body of implemented methods use File | Settings | File Templates.
+    }
+}

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/soap12/SOAP12Constants.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/soap12/SOAP12Constants.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/soap12/SOAP12Constants.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/soap12/SOAP12Constants.java Thu Apr 28 21:08:34 2005
@@ -26,4 +26,42 @@
 
     public String SOAP_ENVELOPE_NAMESPACE_URI =
             "http://www.w3.org/2003/05/soap-envelope";
+
+    public static final String SOAP_ENVELOPE_LOCAL_NAME = "Envelope";
+
+    public static final String SOAP_HEADER_LOCAL_NAME = "Header";
+
+    public static final String SOAP_ROLE = "role";
+    public static final String SOAP_MUSTUNDERSTAND = "mustUnderstand";
+    public static final String SOAP_RELAY = "relay";
+
+    public static final String SOAP_BODY_LOCAL_NAME = "Body";
+
+    // SOAP Faults
+    public static final String SOAP_FAULT_LOCAL_NAME = "Fault";
+
+    // SOAP Fault Code
+    public static final String SOAP_FAULT_CODE_LOCAL_NAME = "Code";
+    public static final String SOAP_FAULT_SUB_CODE_LOCAL_NAME = "SubCode";
+    public static final String SOAP_FAULT_VALUE_LOCAL_NAME = "Value";
+
+    // SOAP Fault Codes
+    public static final String SOAP_FAULT_VALUE_VERSION_MISMATCH = "env:VersionMismatch";
+    public static final String SOAP_FAULT_VALUE_MUST_UNDERSTAND = "env:MustUnderstand";
+    public static final String SOAP_FAULT_VALUE_DATA_ENCODING_UKNOWN = "env:DataEncodingUnknown";
+    public static final String SOAP_FAULT_VALUE_SENDER = "env:Sender";
+    public static final String SOAP_FAULT_VALUE_RECEIVER = "env:Receiver";
+
+    // SOAP Fault Reason
+    public static final String SOAP_FAULT_REASON_LOCAL_NAME = "Reason";
+    public static final String SOAP_FAULT_TEXT_LOCAL_NAME = "Text";
+    public static final String SOAP_FAULT_TEXT_LANG_ATTR_LOCAL_NAME = "lang";
+    public static final String SOAP_FAULT_TEXT_LANG_ATTR_NS_URI = "http://www.w3.org/XML/1998/namespace";
+    public static final String SOAP_FAULT_TEXT_LANG_ATTR_NS_PREFIX = "xml";
+
+    // SOAP Fault Node
+    public static final String SOAP_FAULT_NODE_LOCAL_NAME = "Node";
+
+    // SOAP Fault Detail
+    public static final String SOAP_FAULT_DETAIL_LOCAL_NAME = "Detail";
 }

Modified: webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/OMHeaderBlockTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/OMHeaderBlockTest.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/OMHeaderBlockTest.java (original)
+++ webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/OMHeaderBlockTest.java Thu Apr 28 21:08:34 2005
@@ -36,9 +36,9 @@
 
     public void testSetAndGetActor() {
         String newActorURI = "http://newActor.org";
-        soapHeaderElement.setActor(newActorURI);
-        System.out.println("ActorURI = " + soapHeaderElement.getActor());
-        assertTrue("Actor was not properly set", soapHeaderElement.getActor().equalsIgnoreCase(newActorURI));
+        soapHeaderElement.setRole(newActorURI);
+        System.out.println("ActorURI = " + soapHeaderElement.getRole());
+        assertTrue("Actor was not properly set", soapHeaderElement.getRole().equalsIgnoreCase(newActorURI));
     }
 
     public void testSetAndGetMustUnderstand() {

Modified: webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/SOAPFaultTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/SOAPFaultTest.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/SOAPFaultTest.java (original)
+++ webservices/axis/trunk/java/modules/xml/test/org/apache/axis/om/SOAPFaultTest.java Thu Apr 28 21:08:34 2005
@@ -38,15 +38,14 @@
     }
 
     public void testSOAPFault() throws Exception {
-        soapEnvelope = (SOAPEnvelope) OMTestUtils.getOMBuilder(getTestResourceFile("soap/minimalMessage.xml")).getDocumentElement();
-        SOAPBody soapBody = soapEnvelope.getBody();
-        SOAPFault soapFault = OMFactory.newInstance().createSOAPFault(soapBody, new Exception("Something has gone wrong som where !!"));
-        soapBody.addFault(soapFault);
-        soapFault.setFaultCode(new QName("http://opensource.lk", "Axis", "SOAP-ENV"));
-        assertEquals("faultcode returned is incorrect", soapFault.getFaultCode().getLocalPart(), "Axis");
-        assertEquals("faultcode returned is incorrect", soapFault.getFaultCode().getPrefix(), "SOAP-ENV");
-        soapFault.setFaultActor("Neo");
-        assertEquals("faultactor returned is incorrect", soapFault.getFaultActor(), "Neo");
+//        soapEnvelope = (SOAPEnvelope) OMTestUtils.getOMBuilder(getTestResourceFile("soap/minimalMessage.xml")).getDocumentElement();
+//        SOAPBody soapBody = soapEnvelope.getBody();
+//        SOAPFault soapFault = OMFactory.newInstance().createSOAPFault(soapBody, new Exception("Something has gone wrong som where !!"));
+//        soapBody.addFault(soapFault);
+//        soapFault.setCode(null);
+//        assertEquals("faultcode returned is incorrect", soapFault.getCode().getLocalName(), "Axis");
+//        assertEquals("faultcode returned is incorrect", soapFault.getCode().getNamespace().getPrefix(), "SOAP-ENV");
+
 
 
     }
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeader.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeader.java Thu Apr 28 21:08:34 2005
@@ -40,55 +40,55 @@
     /**
      * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
      * objects in this <CODE>SOAPHeader</CODE> object that have the
      * the specified actor. An actor is a global attribute that
      * indicates the intermediate parties to whom the message should
      * be sent. An actor receives the message and then sends it to
      * the next actor. The default actor is the ultimate intended
      * recipient for the message, so if no actor attribute is
      * included in a <CODE>SOAPHeader</CODE> object, the message is
      * sent to its ultimate destination.
      *
      * @param actor a <CODE>String</CODE> giving the
      *              URI of the actor for which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
      *         SOAPHeaderBlock</CODE> objects that contain the
-     *         specified actor
+     *         specified role
      * @see #extractHeaderBlocks(java.lang.String) extractHeaderBlocks(java.lang.String)
      */
-    public abstract Iterator examineHeaderBlocks(String actor);
+    public abstract Iterator examineHeaderBlocks(String role);
 
     /**
      * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
      * objects in this <CODE>SOAPHeader</CODE> object that have
      * the the specified actor and detaches them from this <CODE>
      * SOAPHeader</CODE> object.
      * <P>This method allows an actor to process only the parts of
      * the <CODE>SOAPHeader</CODE> object that apply to it and to
      * remove them before passing the message on to the next
-     * actor.
+     * role.
      *
      * @param actor a <CODE>String</CODE> giving the
      *              URI of the actor for which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
      *         SOAPHeaderBlock</CODE> objects that contain the
-     *         specified actor
+     *         specified role
      * @see #examineHeaderBlocks(java.lang.String) examineHeaderBlocks(java.lang.String)
      */
-    public abstract Iterator extractHeaderBlocks(String actor);
+    public abstract Iterator extractHeaderBlocks(String role);
 
     /**
      * Returns an <code>Iterator</code> over all the
      * <code>SOAPHeaderBlock</code> objects in this <code>SOAPHeader</code>
      * object that have the specified actor and that have a MustUnderstand
      * attribute whose value is equivalent to <code>true</code>.
      *
      * @param actor a <code>String</code> giving the URI of the actor for which
      *              to search
      * @return an <code>Iterator</code> object over all the
      *         <code>SOAPHeaderBlock</code> objects that contain the
      *         specified actor and are marked as MustUnderstand
      */
-    public abstract Iterator examineMustUnderstandHeaderBlocks(String actor);
+    public abstract Iterator examineMustUnderstandHeaderBlocks(String role);
 
     /**
      * Returns an <code>Iterator</code> over all the
@@ -40,55 +40,55 @@
      * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
      * objects in this <CODE>SOAPHeader</CODE> object that have the
-     * the specified actor. An actor is a global attribute that
+     * the specified role. An role is a global attribute that
      * indicates the intermediate parties to whom the message should
@@ -40,55 +40,55 @@
      * indicates the intermediate parties to whom the message should
-     * be sent. An actor receives the message and then sends it to
-     * the next actor. The default actor is the ultimate intended
-     * recipient for the message, so if no actor attribute is
+     * be sent. An role receives the message and then sends it to
+     * the next role. The default role is the ultimate intended
+     * recipient for the message, so if no role attribute is
      * included in a <CODE>SOAPHeader</CODE> object, the message is
      * sent to its ultimate destination.
@@ -40,55 +40,55 @@
      * sent to its ultimate destination.
      *
-     * @param actor a <CODE>String</CODE> giving the
-     *              URI of the actor for which to search
+     * @param role a <CODE>String</CODE> giving the
+     *              URI of the role for which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
      *         SOAPHeaderBlock</CODE> objects that contain the
@@ -40,55 +40,55 @@
      * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
      * objects in this <CODE>SOAPHeader</CODE> object that have
-     * the the specified actor and detaches them from this <CODE>
+     * the the specified role and detaches them from this <CODE>
      * SOAPHeader</CODE> object.
@@ -40,55 +40,55 @@
      * SOAPHeader</CODE> object.
-     * <P>This method allows an actor to process only the parts of
+     * <P>This method allows an role to process only the parts of
      * the <CODE>SOAPHeader</CODE> object that apply to it and to
      * remove them before passing the message on to the next
@@ -40,55 +40,55 @@
      *
-     * @param actor a <CODE>String</CODE> giving the
-     *              URI of the actor for which to search
+     * @param role a <CODE>String</CODE> giving the
+     *              URI of the role for which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
      *         SOAPHeaderBlock</CODE> objects that contain the
@@ -40,55 +40,55 @@
      * Returns an <code>Iterator</code> over all the
      * <code>SOAPHeaderBlock</code> objects in this <code>SOAPHeader</code>
-     * object that have the specified actor and that have a MustUnderstand
+     * object that have the specified role and that have a MustUnderstand
      * attribute whose value is equivalent to <code>true</code>.
      *
@@ -40,55 +40,55 @@
      * attribute whose value is equivalent to <code>true</code>.
      *
-     * @param actor a <code>String</code> giving the URI of the actor for which
+     * @param role a <code>String</code> giving the URI of the role for which
      *              to search
      * @return an <code>Iterator</code> object over all the
@@ -40,55 +40,55 @@
      * @return an <code>Iterator</code> object over all the
      *         <code>SOAPHeaderBlock</code> objects that contain the
-     *         specified actor and are marked as MustUnderstand
+     *         specified role and are marked as MustUnderstand
      */

Modified: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeaderBlock.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/SOAPHeaderBlock.java?rev=165258&r1=165257&r2=165258&view=diff
==============================================================================
--- webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderImpl.java (original)
+++ webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPHeaderImpl.java Thu Apr 28 21:08:34 2005
@@ -15,22 +15,14 @@
 */
 package org.apache.axis.om.impl.llom;
 
-import java.util.ArrayList;
-import java.util.Iterator;
-
-import javax.xml.namespace.QName;
-
-import org.apache.axis.om.OMElement;
-import org.apache.axis.om.OMException;
-import org.apache.axis.om.OMNamespace;
-import org.apache.axis.om.OMXMLParserWrapper;
-import org.apache.axis.om.SOAPEnvelope;
-import org.apache.axis.om.SOAPHeader;
-import org.apache.axis.om.SOAPHeaderBlock;
-import org.apache.axis.om.OMNode;
+import org.apache.axis.om.*;
 import org.apache.axis.om.impl.llom.soap11.SOAP11Constants;
 import org.apache.axis.om.impl.llom.traverse.OMChildrenWithSpecificAttributeIterator;
 
+import javax.xml.namespace.QName;
+import java.util.ArrayList;
+import java.util.Iterator;
+
 /**
  * Class SOAPHeaderImpl
  */
@@ -53,28 +45,28 @@
      * @param builder
      */
     public SOAPHeaderImpl(SOAPEnvelope envelope, OMXMLParserWrapper builder) {
-        super(
-                SOAPConstants.HEADER_LOCAL_NAME,
+        super(SOAPConstants.HEADER_LOCAL_NAME,
                 (envelope == null) ? null : envelope.getNamespace(),
                 envelope,
                 builder);
     }
 
     /**
-     * Creates a new <CODE>SOAPHeaderBlock</CODE> object
-     * initialized with the specified name and adds it to this
-     * <CODE>SOAPHeader</CODE> object.
+     * Creates a new <CODE>SOAPHeaderBlock</CODE> object initialized with the
+     * specified name and adds it to this <CODE>SOAPHeader</CODE> object.
      *
      * @param localName
      * @param ns
-     * @return the new <CODE>SOAPHeaderBlock</CODE> object that
-     *         was inserted into this <CODE>SOAPHeader</CODE>
-     *         object
+     * @return the new <CODE>SOAPHeaderBlock</CODE> object that was inserted
+     *         into this <CODE>SOAPHeader</CODE> object
      * @throws org.apache.axis.om.OMException if a SOAP error occurs
      * @throws OMException
      */
     public SOAPHeaderBlock addHeaderBlock(String localName, OMNamespace ns)
             throws OMException {
+        if (ns == null || ns.getName() == null || "".equals(ns.getName())) {
+            throw new OMException("All the SOAP Header blocks should be namespace qualified");
+        }
         SOAPHeaderBlock soapHeaderBlock =
                 new SOAPHeaderBlockImpl(localName, ns);
         this.addChild(soapHeaderBlock);
@@ -83,93 +75,84 @@
     }
 
     /**
-     * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
-     * objects in this <CODE>SOAPHeader</CODE> object that have the
-     * the specified actor. An actor is a global attribute that
-     * indicates the intermediate parties to whom the message should
-     * be sent. An actor receives the message and then sends it to
-     * the next actor. The default actor is the ultimate intended
-     * recipient for the message, so if no actor attribute is
-     * included in a <CODE>SOAPHeader</CODE> object, the message is
-     * sent to its ultimate destination.
+     * Returns a list of all the <CODE>SOAPHeaderBlock</CODE> objects in this
+     * <CODE>SOAPHeader</CODE> object that have the the specified actor. An
+     * actor is a global attribute that indicates the intermediate parties to
+     * whom the message should be sent. An actor receives the message and then
+     * sends it to the next actor. The default actor is the ultimate intended
+     * recipient for the message, so if no actor attribute is included in a
+     * <CODE>SOAPHeader</CODE> object, the message is sent to its ultimate
+     * destination.
      *
      * @param paramActor      a <CODE>String</CODE> giving the
      *                   URI of the actor for which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
-     *         SOAPHeaderBlock</CODE> objects that contain the
-     *         specified actor
+     *         SOAPHeaderBlock</CODE> objects that contain the specified actor
      * @see #extractHeaderBlocks(String) extractHeaderBlocks(java.lang.String)
      */
-    public Iterator examineHeaderBlocks(String paramActor) {
+    public Iterator examineHeaderBlocks(String paramRole) {
         Iterator headerBlocksIter = this.getChildren();
+        ArrayList headersWithGivenActor = new ArrayList();
         while (headerBlocksIter.hasNext()) {
             Object o = headerBlocksIter.next();
             if (o instanceof SOAPHeaderBlock) {
                 SOAPHeaderBlock soapHeaderBlock = (SOAPHeaderBlock) o;
-                String actor = soapHeaderBlock.getActor();
-                if ((actor != null) && actor.equalsIgnoreCase(paramActor)) {
-
-                    // headerBlocksIter.
+                String role = soapHeaderBlock.getRole();
+                if ((role != null) && role.equalsIgnoreCase(paramRole)) {
+                    headersWithGivenActor.add(soapHeaderBlock);
                 }
             }
         }
-        return headerBlocksIter;
+        return headersWithGivenActor.iterator();
     }
 
     /**
-     * Returns a list of all the <CODE>SOAPHeaderBlock</CODE>
-     * objects in this <CODE>SOAPHeader</CODE> object that have
-     * the the specified actor and detaches them from this <CODE>
-     * SOAPHeader</CODE> object.
-     * <P>This method allows an actor to process only the parts of
-     * the <CODE>SOAPHeader</CODE> object that apply to it and to
-     * remove them before passing the message on to the next
-     * actor.
+     * Returns a list of all the <CODE>SOAPHeaderBlock</CODE> objects in this
+     * <CODE>SOAPHeader</CODE> object that have the the specified actor and
+     * detaches them from this <CODE> SOAPHeader</CODE> object. <P>This method
+     * allows an actor to process only the parts of the <CODE>SOAPHeader</CODE>
+     * object that apply to it and to remove them before passing the message on
+     * to the next actor.
      *
-     * @param actor a <CODE>String</CODE> giving the
-     *              URI of the actor for which to search
+     * @param actor a <CODE>String</CODE> giving the URI of the actor for which
+     *              to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>
-     *         SOAPHeaderBlock</CODE> objects that contain the
-     *         specified actor
+     *         SOAPHeaderBlock</CODE> objects that contain the specified actor
      * @see #examineHeaderBlocks(String) examineHeaderBlocks(java.lang.String)
      */
     public Iterator extractHeaderBlocks(String actor) {
-        return new OMChildrenWithSpecificAttributeIterator(
-                getFirstChild(),
-                new QName(
-                        SOAP11Constants.SOAP_ENVELOPE_NAMESPACE_URI,
+        return new OMChildrenWithSpecificAttributeIterator(getFirstChild(),
+                new QName(SOAP11Constants.SOAP_ENVELOPE_NAMESPACE_URI,
                         SOAPConstants.ATTR_ACTOR),
                 actor,
                 true);
     }
 
     /**
-     * Returns an <code>Iterator</code> over all the
-     * <code>SOAPHeaderBlock</code> objects in this <code>SOAPHeader</code>
-     * object that have the specified actor and that have a MustUnderstand
-     * attribute whose value is equivalent to <code>true</code>.
+     * Returns an <code>Iterator</code> over all the <code>SOAPHeaderBlock</code>
+     * objects in this <code>SOAPHeader</code> object that have the specified
+     * actor and that have a MustUnderstand attribute whose value is equivalent
+     * to <code>true</code>.
      *
      * @param actor a <code>String</code> giving the URI of the actor for which
      *              to search
      * @return an <code>Iterator</code> object over all the
-     *         <code>SOAPHeaderBlock</code> objects that contain the
-     *         specified actor and are marked as MustUnderstand
+     *         <code>SOAPHeaderBlock</code> objects that contain the specified
+     *         actor and are marked as MustUnderstand
      */
     public Iterator examineMustUnderstandHeaderBlocks(String actor) {
-        return new OMChildrenWithSpecificAttributeIterator(
-                getFirstChild(),
-                new QName(
-                        SOAP11Constants.SOAP_ENVELOPE_NAMESPACE_URI,
+        return new OMChildrenWithSpecificAttributeIterator(getFirstChild(),
+                new QName(SOAP11Constants.SOAP_ENVELOPE_NAMESPACE_URI,
                         SOAPConstants.ATTR_ACTOR),
                 actor,
                 false);
     }
 
     /**
-     * Returns an <code>Iterator</code> over all the
-     * <code>SOAPHeaderBlock</code> objects in this <code>SOAPHeader</code>
-     * object.
-     * Not that this will return elements containing the QName (http://schemas.xmlsoap.org/soap/envelope/, Header)
+     * Returns an <code>Iterator</code> over all the <code>SOAPHeaderBlock</code>
+     * objects in this <code>SOAPHeader</code> object. Not that this will return
+     * elements containing the QName (http://schemas.xmlsoap.org/soap/envelope/,
+     * Header)
      *
      * @return an <code>Iterator</code> object over all the
      *         <code>SOAPHeaderBlock</code> objects contained by this
@@ -180,9 +163,9 @@
     }
 
     /**
-     * Returns an <code>Iterator</code> over all the
-     * <code>SOAPHeaderBlock</code> objects in this <code>SOAPHeader </code>
-     * object and detaches them from this <code>SOAPHeader</code> object.
+     * Returns an <code>Iterator</code> over all the <code>SOAPHeaderBlock</code>
+     * objects in this <code>SOAPHeader </code> object and detaches them from
+     * this <code>SOAPHeader</code> object.
      *
      * @return an <code>Iterator</code> object over all the
      *         <code>SOAPHeaderBlock</code> objects contained by this
@@ -204,8 +187,8 @@
         node = header;
         
         while (node != null) {
-            if (node.getType()==OMNode.ELEMENT_NODE){
-                header = (OMElement)node;
+            if (node.getType() == OMNode.ELEMENT_NODE) {
+                header = (OMElement) node;
                 if (nsURI.equals(header.getNamespace().getName())) {
                     headers.add(header);
                 }
@@ -83,93 +75,84 @@
      *
-     * @param paramActor      a <CODE>String</CODE> giving the
-     *                   URI of the actor for which to search
+     * @param paramRole a <CODE>String</CODE> giving the URI of the actor for
+     *                  which to search
      * @return an <CODE>Iterator</CODE> object over all the <CODE>

Added: webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPTextImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/modules/xml/src/org/apache/axis/om/impl/llom/SOAPTextImpl.java?rev=165258&view=auto
==============================================================================